@@ -1,6 +1,6 @@
 #!/usr/bin/python
+# -*- coding: utf-8 -*-
 # vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
-
 import os
 import sys
 import argparse
@@ -11,12 +11,17 @@ import ConfigParser
 
 import global_mod as gm
 from command_list import CommandList
+#from command_url import CommandUrl
 from command_init import CommandInit
 from command_push import CommandPush
 from command_pull import CommandPull
 from command_mkdir import CommandMkdir
 from command_search import CommandSearch
 from command_trash import CommandTrash
+from gdrv import command_share, command_url
+
+reload(sys)
+sys.setdefaultencoding('utf-8')
 
 lgr = logging.getLogger()
 lgr.setLevel(logging.ERROR)
@@ -98,6 +103,8 @@ def main():
                       'mkdir': CommandMkdir(subparser),
                       'search': CommandSearch(subparser),
                       'trash': CommandTrash(subparser),
+                      'url': command_url.CommandUrl(subparser),
+                      'share': command_share.CommandShare(subparser),
                       'init': CommandInit(subparser)}
 
     args = parser.parse_args()
